import { ChangeEventHandler, HTMLInputTypeAttribute } from 'react';
import { RegisterOptions } from 'react-hook-form';
import { ConnectedForm, ConnectedFormGroup, ConnectedFormGroupProps, ConnectedFormProps } from '.';
import { ConnectedField, SubmitContextProps } from './types';
interface ConnectedGroupStrictProps<Values extends {}> {
    <Name extends keyof Values, Component extends ConnectedField>(props: {
        name: Name;
    } & ConnectedFormGroupProps<Component>): ReturnType<typeof ConnectedFormGroup>;
}
interface UseConnectedFormProps<Values, Rules extends {
    [Key in keyof Values]?: RegisterOptions;
}> {
    defaultValues: Values;
    validationRules: Partial<Rules>;
    watchedFields?: {
        fields: (keyof Values)[];
        watchHandler: (arg0: (keyof Values)[]) => void;
    };
}
interface ConnectedFormStrictProps<Values extends {}, Rules extends {
    [Key in keyof Values]?: RegisterOptions;
}> extends UseConnectedFormProps<Values, Rules> {
    (props: UseConnectedFormProps<Values, Rules> & ConnectedFormProps<Values>): ReturnType<typeof ConnectedForm>;
}
export declare const useConnectedForm: <Values extends {}, ValidationRules extends { [K in keyof Values]: Partial<{
    required: string | import("react-hook-form").ValidationRule<boolean>;
    min: import("react-hook-form").ValidationRule<string | number>;
    max: import("react-hook-form").ValidationRule<string | number>;
    maxLength: import("react-hook-form").ValidationRule<number>;
    minLength: import("react-hook-form").ValidationRule<number>;
    pattern: import("react-hook-form").ValidationRule<RegExp>;
    validate: import("react-hook-form").Validate<any> | Record<string, import("react-hook-form").Validate<any>>;
    valueAsNumber: boolean;
    valueAsDate: boolean;
    value: any;
    setValueAs: (value: any) => any;
    shouldUnregister?: boolean | undefined;
    onChange?: ((event: any) => void) | undefined;
    onBlur?: ((event: any) => void) | undefined;
    disabled: boolean;
    deps: string[];
}>; }>({ defaultValues, validationRules, watchedFields, }: UseConnectedFormProps<Values, Partial<ValidationRules>>) => {
    ConnectedFormGroup: ConnectedGroupStrictProps<Values>;
    ConnectedForm: ConnectedFormStrictProps<Values, ValidationRules>;
    connectedFormProps: {
        defaultValues: Values;
        validationRules: Partial<Partial<ValidationRules>>;
        watchedFields: {
            fields: (keyof Values)[];
            watchHandler: (arg0: (keyof Values)[]) => void;
        } | undefined;
    };
};
export declare const submitSuccessStatus: (wasSubmitSuccessful: boolean | undefined, isSubmitSuccessful: boolean | undefined) => boolean | undefined;
export declare const useFormState: () => {
    control: import("react-hook-form").Control<import("react-hook-form").FieldValues, object>;
    errors: {
        [x: string]: any;
    };
    formState: import("react-hook-form").FormState<import("react-hook-form").FieldValues>;
    getValues: import("react-hook-form").UseFormGetValues<import("react-hook-form").FieldValues>;
    isDirty: boolean;
    isDisabled: boolean | undefined;
    register: import("react-hook-form").UseFormRegister<import("react-hook-form").FieldValues>;
    reset: import("react-hook-form").UseFormReset<import("react-hook-form").FieldValues>;
    setError: import("react-hook-form").UseFormSetError<import("react-hook-form").FieldValues>;
    setValue: import("react-hook-form").UseFormSetValue<import("react-hook-form").FieldValues>;
    showRequired: boolean | undefined;
    useFieldArray: <TFieldValues extends import("react-hook-form").FieldValues = import("react-hook-form").FieldValues, TFieldArrayName extends import("react-hook-form").ArrayPath<TFieldValues> = import("react-hook-form").ArrayPath<TFieldValues>, TKeyName extends string = "id">(props: import("react-hook-form").UseFieldArrayProps<TFieldValues, TFieldArrayName, TKeyName>) => import("react-hook-form").UseFieldArrayReturn<TFieldValues, TFieldArrayName, TKeyName>;
    validationRules: {
        string?: Partial<{
            required: string | import("react-hook-form").ValidationRule<boolean>;
            min: import("react-hook-form").ValidationRule<string | number>;
            max: import("react-hook-form").ValidationRule<string | number>;
            maxLength: import("react-hook-form").ValidationRule<number>;
            minLength: import("react-hook-form").ValidationRule<number>;
            pattern: import("react-hook-form").ValidationRule<RegExp>;
            validate: import("react-hook-form").Validate<any> | Record<string, import("react-hook-form").Validate<any>>;
            valueAsNumber: boolean;
            valueAsDate: boolean;
            value: any;
            setValueAs: (value: any) => any;
            shouldUnregister?: boolean | undefined;
            onChange?: ((event: any) => void) | undefined;
            onBlur?: ((event: any) => void) | undefined;
            disabled: boolean;
            deps: string[];
        }> | undefined;
    } | undefined;
    watch: import("react-hook-form").UseFormWatch<import("react-hook-form").FieldValues>;
    clearErrors: import("react-hook-form").UseFormClearErrors<import("react-hook-form").FieldValues>;
};
interface useFieldProps extends SubmitContextProps {
    name: string;
}
export declare const useField: ({ name, disabled, loading }: useFieldProps) => {
    control: import("react-hook-form").Control<import("react-hook-form").FieldValues, object>;
    error: any;
    isDisabled: boolean;
    /**
     * Keep track of the first error in this form.
     * This is so we only add the correct aria-live props on the first error.
     */
    isFirstError: boolean;
    isLoading: boolean | undefined;
    isRequired: boolean;
    register: import("react-hook-form").UseFormRegister<import("react-hook-form").FieldValues>;
    validation: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: import("react-hook-form").Validate<any> | Record<string, import("react-hook-form").Validate<any>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: any;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string[];
    }> | undefined;
    ref: import("react-hook-form").UseFormRegisterReturn;
    setValue: import("react-hook-form").UseFormSetValue<import("react-hook-form").FieldValues>;
    setError: import("react-hook-form").UseFormSetError<import("react-hook-form").FieldValues>;
    showRequired: boolean | undefined;
};
export declare const useSubmitState: ({ loading, disabled }: SubmitContextProps) => {
    isLoading: boolean | undefined;
    isDisabled: boolean;
};
interface GetInitialFormValueProps {
    name: string;
    setLocalValue: (value: string) => void;
    watchUpdateKeyName?: string;
    defaultValue: string | boolean;
}
export declare const useGetInitialFormValue: ({ name, setLocalValue, watchUpdateKeyName, defaultValue, }: GetInitialFormValueProps) => void;
export declare const USE_DEBOUNCED_FIELD_DIRTY_KEY = "";
/**
 * The HTMLInputTypeAttribute type includes
 * (string | {}) which is a "hack" that allows ts autocomplete
 * to suggest the actual input types while also accepting any random string.
 * However, this type breaks down the overall type for the `type` prop below
 * due to it being passed through a few layers of <T extends ...>
 * and it ends up just being a string with no autocomplete.
 *
 * I'm extracting the relevant, usable types here from HTMLInputTypeAttribute
 * but would love to figure out a programatic solution.
 *
 * See https://github.com/Microsoft/TypeScript/issues/12215#issuecomment-414783301
 * for something that I think could be modified to make this better
 * but I couldn't get it to work
 */
type InputTypes = Extract<HTMLInputTypeAttribute, 'number' | 'color' | 'date' | 'datetime-local' | 'time' | 'image' | 'checkbox' | 'text' | 'hidden' | 'password' | 'radio' | 'range' | 'email' | 'search' | 'month' | 'tel' | 'time' | 'url' | 'week'> | 'textarea' | 'select';
type DebouncedFieldProps<T extends InputTypes> = Omit<GetInitialFormValueProps, 'setLocalValue' | 'defaultValue'> & Pick<useFieldProps, 'loading' | 'disabled' | 'name'> & {
    type: T;
    shouldDirtyOnChange?: boolean;
};
export declare function useDebouncedField<T extends InputTypes>({ name, watchUpdateKeyName, disabled, loading, type, shouldDirtyOnChange, }: DebouncedFieldProps<T>): {
    onBlur: () => void;
    onChange: ChangeEventHandler<HTMLInputElement | HTMLSelectElement | HTMLTextAreaElement>;
    value: T extends "checkbox" ? boolean : string;
    ref: import("react-hook-form").UseFormRegisterReturn;
    error: any;
    isDisabled: boolean;
    control: import("react-hook-form").Control<import("react-hook-form").FieldValues, object>;
    showRequired: boolean | undefined;
    isLoading: boolean | undefined;
    validation: Partial<{
        required: string | import("react-hook-form").ValidationRule<boolean>;
        min: import("react-hook-form").ValidationRule<string | number>;
        max: import("react-hook-form").ValidationRule<string | number>;
        maxLength: import("react-hook-form").ValidationRule<number>;
        minLength: import("react-hook-form").ValidationRule<number>;
        pattern: import("react-hook-form").ValidationRule<RegExp>;
        validate: import("react-hook-form").Validate<any> | Record<string, import("react-hook-form").Validate<any>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: any;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string[];
    }> | undefined;
    setError: import("react-hook-form").UseFormSetError<import("react-hook-form").FieldValues>;
    isRequired: boolean;
    isFirstError: boolean;
};
export {};
