import { ComponentProps } from 'react';
import * as React from 'react';
import { FillButton } from '../Button';
import { ModalContainer } from './elements';
import { ModalBaseProps } from './types';
interface DialogButtonProps {
    children: React.ReactNode;
    href?: string;
    onClick?: ComponentProps<typeof FillButton>['onClick'];
    disabled?: boolean;
}
export interface ModalView extends Omit<ModalBaseProps, 'headingLevel' | 'onRequestClose'> {
    children: React.ReactNode;
    nextCta?: DialogButtonProps;
    confirmCta?: DialogButtonProps;
    cancelCta?: DialogButtonProps;
}
export interface SingleViewModalProps extends ModalBaseProps {
    size?: ComponentProps<typeof ModalContainer>['size'];
    /**
     * Whether to hide the default close button and pass your own through children
     */
    hideCloseButton?: boolean;
    /**
     * Whether to show scrollbar on content overflow
     */
    scrollable?: boolean;
    views?: never;
    /**
     * Whether to disable X button at top right of modal
     */
    closeDisabled?: boolean;
}
export interface MultiViewModalProps extends Omit<ModalBaseProps, 'children' | 'image'> {
    children?: never;
    image?: never;
    size?: ComponentProps<typeof ModalContainer>['size'];
    /**
     * Whether to hide the default close button and pass your own through children
     */
    hideCloseButton?: boolean;
    /**
     * Whether to show scrollbar on content overflow
     */
    scrollable?: boolean;
    /**
     * Optional array of multiple screens
     */
    views: ModalView[];
    /**
     * Whether to disable X button at top right of modal
     */
    closeDisabled?: boolean;
}
export type ModalProps = SingleViewModalProps | MultiViewModalProps;
export declare const Modal: React.FC<ModalProps>;
export {};
